#line 2 "fitsy++/envilex.C"

#line 4 "fitsy++/envilex.C"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

    /* The c++ scanner is a mess. The FlexLexer.h header file relies on the
     * following macro. This is required in order to pass the c++-multiple-scanners
     * test in the regression suite. We get reports that it breaks inheritance.
     * We will address this in a future release of flex, or omit the C++ scanner
     * altogether.
     */
    #define yyFlexLexer enviFlexLexer

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
typedef uint64_t flex_uint64_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */
#include <iostream> 
#include <errno.h>
#include <cstdlib>
#include <cstring>
/* end standard C++ headers. */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{

	std::istream* yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

void *envialloc (yy_size_t  );
void *envirealloc (void *,yy_size_t  );
void envifree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

#define yytext_ptr yytext

#include <FlexLexer.h>

int yyFlexLexer::yywrap() { return 1; }

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (yy_size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 72
#define YY_END_OF_BUFFER 73
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[282] =
    {   0,
        0,    0,    2,    2,    0,    0,   73,   71,   68,   70,
       71,   71,   71,   64,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,    3,    2,    1,   63,   61,   62,
       63,   60,   59,   63,   56,   59,    4,   68,   69,    0,
       64,   66,   65,   64,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,    6,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,    2,   61,    0,   56,   59,

       56,   58,   57,   59,    0,    0,    0,   65,   67,   67,
       11,   12,   13,   14,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   32,   67,   67,    7,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,    0,    0,    0,   59,   57,   65,    0,   66,
       67,    9,   15,   17,   67,   67,   67,   16,   67,   22,
       67,   23,   24,   67,   67,   26,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   40,   67,   67,   67,   67,
       67,   67,   67,   48,   67,   67,   51,   67,   67,   67,

       57,    0,   58,   67,   10,    5,   67,   67,   67,   21,
       67,   67,   67,   67,   30,   31,   33,   34,   67,   37,
       38,   67,   42,   67,   67,   45,   67,   67,   67,   67,
       52,   53,   67,   67,   67,   67,   20,   25,   27,   67,
       29,   35,   39,   67,   67,   67,   67,   47,   67,   50,
       54,   67,    8,   18,   67,   67,   36,   67,   67,   44,
       46,   49,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   28,   41,   67,   55,   19,   43,
        0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    5,    6,    7,    8,    1,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    1,    1,    1,
        1,    1,    1,    1,   10,   11,   12,   13,   14,   15,
       16,   17,   18,   19,   20,   21,   22,   23,   24,   25,
       26,   27,   28,   29,   30,   31,   32,   33,   34,   35,
        1,    1,    1,    1,    1,    1,   36,   37,   38,   39,

       40,   41,   42,   43,   44,   45,   20,   46,   47,   48,
       49,   50,   51,   52,   53,   54,   55,   56,   57,   58,
       59,   60,   61,    1,   62,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[63] =
    {   0,
        1,    1,    2,    1,    1,    1,    3,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        1,    1
    } ;

static yyconst flex_int16_t yy_base[287] =
    {   0,
        0,    0,  806,  805,   62,  124,  807,  810,  800,  810,
      788,   64,  781,   66,   78,  179,  781,   68,   69,  127,
       71,   75,  128,   76,   77,   80,  150,  148,  132,  231,
      144,   91,   83,  102,  810,    0,  810,  810,  786,  810,
       88,  810,   92,  778,  141,  778,  810,  783,  810,  775,
      187,  134,  190,  197,  775,  212,  153,  202,  201,  227,
      200,  204,  226,  246,  228,  145,  210,  232,  236,  254,
      255,  258,  274,  270,  282,  286,  278,  280,  772,  297,
      289,  288,  296,  300,  311,  294,  303,  306,  316,   95,
      327,  325,  322,  323,  330,    0,  776,  768,  349,  767,

      351,  353,  359,  375,  365,  383,  765,  220,  369,  387,
      765,  764,  763,  761,  371,  393,  379,  394,  386,  389,
      398,  400,  397,  409,  402,  407,  404,  408,  427,  405,
      428,  414,  760,  431,  429,  437,  446,  456,  443,  439,
      458,  467,  451,  470,  453,  463,  465,  474,  475,  479,
      477,  484,  505,  512,  757,  334,  514,  756,  751,  750,
      494,  501,  750,  746,  518,  517,  519,  739,  520,  725,
      523,  687,  684,  527,  528,  636,  530,  532,  531,  535,
      537,  540,  562,  548,  544,  629,  565,  569,  577,  573,
      584,  580,  550,  570,  587,  593,  558,  598,  596,  600,

      544,  542,  541,  606,  541,  534,  604,  605,  588,  503,
      603,  621,  610,  619,  491,  486,  454,  440,  624,  410,
      626,  630,  370,  631,  644,  363,  649,  654,  652,  657,
      356,  658,  659,  662,  651,  663,  347,  345,  341,  669,
      338,  666,  268,  667,  674,  679,  685,  262,  683,  256,
      238,  693,  216,  206,  689,  712,  174,  690,  715,  172,
      156,  152,  719,  696,  589,  707,  716,  709,  721,  722,
      734,  738,  736,  744,  133,  110,  741,  103,   97,   94,
      810,  792,  796,   94,  800,  802
    } ;

static yyconst flex_int16_t yy_def[287] =
    {   0,
      281,    1,  282,  282,  283,  283,  281,  281,  281,  281,
      281,  281,  281,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  281,  285,  281,  281,  281,  281,
      281,  281,  286,  281,  286,  286,  281,  281,  281,  281,
      281,  281,  281,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,  285,  281,  281,  281,  286,

      286,  281,  281,  286,  281,  281,  281,  284,  284,  284,
      284,  284,  284,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  281,  281,  281,  286,  286,  281,  281,  281,
      284,  284,  284,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,  284,  284,  284,  284,  284,

      281,  281,  281,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,  284,  284,  284,  284,  284,
        0,  281,  281,  281,  281,  281
    } ;

static yyconst flex_int16_t yy_nxt[873] =
    {   0,
        8,    9,   10,   11,   12,    8,   12,   13,   14,   15,
       16,   17,   18,   19,   20,   21,   22,   23,   17,   17,
       24,   25,   26,   27,   28,   17,   29,   30,   31,   32,
       33,   34,   17,   17,   17,   15,   16,   17,   18,   19,
       20,   21,   22,   23,   17,   24,   25,   26,   27,   28,
       17,   29,   30,   31,   32,   33,   34,   17,   17,   17,
       35,    8,   38,   39,   40,   38,   41,   42,   43,   44,
       45,   50,   51,   53,   54,  281,  281,   63,  281,   56,
       70,   64,  281,  281,  281,  281,   75,  281,   71,   77,
      281,   65,   94,   74,   76,   98,   99,   55,  281,   98,

      101,  281,  281,   63,  281,   56,   70,   64,   57,  281,
      281,   95,   75,   93,   71,   77,   65,  281,   94,   74,
       76,  147,   38,   47,   38,   39,   40,   38,   41,   42,
       43,   44,   45,   57,  281,  281,   66,   95,   93,  281,
      281,   84,   52,   72,   67,   85,  147,  106,  103,  101,
       73,  281,  281,   68,  104,  281,  121,  281,   69,  281,
      281,   91,   66,  281,   78,   81,  109,   84,   82,   72,
       67,   85,   79,  106,   83,   73,   80,   92,   68,  281,
      104,  281,  121,   69,   38,   47,  281,   91,   58,   59,
       78,   81,  109,   82,   53,   51,   60,   79,   52,   83,

      105,   80,   92,  105,   53,   54,   61,  281,  281,  281,
       56,  281,   62,  281,   58,   59,  107,  281,  107,  281,
      108,  111,   60,  281,  110,  114,  105,  281,  108,  105,
      122,   61,  115,  281,  281,  281,   56,   62,  281,  281,
       86,  123,   87,  281,   88,  281,  111,  112,   89,  110,
      114,  113,  124,  281,  116,  122,  117,  115,  120,   90,
      118,  281,  281,  281,  126,  281,   86,  123,   87,  281,
       88,  125,  112,  119,   89,  281,  113,  281,  124,  116,
      127,  281,  117,  120,   90,  281,  118,  281,  128,  281,
      126,  130,  131,  281,  136,  281,  281,  125,  119,  135,

      132,  281,  129,  281,  281,  127,  133,  281,  134,  137,
      281,  139,  144,  281,  128,  143,  130,  131,  281,  140,
      136,  138,  141,  281,  135,  142,  132,  129,  145,  281,
      281,  133,  281,  134,  281,  137,  139,  281,  144,  150,
      143,  281,  157,  151,  140,  281,  138,  141,  281,  149,
      146,  142,  281,  145,  281,  148,  103,   99,  103,  101,
      152,  102,  153,  281,  104,  150,  154,  102,  151,  107,
      281,  107,  153,  158,  149,  146,  281,  281,  281,  155,
      148,  156,  281,  157,  163,  152,  281,  159,  153,  159,
      104,  160,  154,  281,  281,  161,  281,  167,  153,  162,

      281,  281,  164,  166,  281,  281,  168,  281,  165,  281,
      163,  281,  281,  170,  281,  281,  281,  281,  171,  174,
      161,  281,  178,  167,  173,  162,  169,  175,  164,  166,
      172,  176,  168,  165,  281,  281,  281,  180,  281,  170,
      177,  179,  182,  171,  281,  174,  281,  281,  178,  173,
      281,  169,  175,  281,  181,  172,  176,  187,  281,  184,
      281,  281,  180,  281,  183,  281,  177,  179,  182,  185,
      281,  186,  281,  188,  281,  190,  194,  281,  195,  181,
      193,  281,  281,  187,  281,  184,  281,  189,  197,  183,
      191,  281,  192,  281,  196,  185,  186,  200,  281,  188,

      190,  281,  194,  204,  195,  193,  199,  198,  281,  155,
      281,  155,  189,  201,  197,  191,  202,  192,  202,  196,
      203,  281,  157,  200,  281,  281,  281,  281,  205,  204,
      281,  199,  198,  206,  281,  281,  210,  281,  281,  281,
      211,  281,  281,  209,  281,  208,  207,  281,  281,  203,
      203,  281,  201,  205,  212,  281,  213,  281,  215,  206,
      214,  216,  210,  217,  221,  281,  211,  218,  209,  281,
      208,  207,  281,  228,  220,  219,  281,  281,  222,  212,
      281,  213,  223,  215,  281,  214,  216,  281,  217,  221,
      224,  281,  218,  225,  281,  281,  281,  226,  228,  220,

      281,  219,  227,  281,  222,  281,  230,  281,  223,  232,
      281,  281,  281,  281,  237,  229,  224,  281,  225,  270,
      233,  234,  236,  226,  235,  231,  281,  227,  281,  238,
      240,  281,  230,  281,  239,  232,  281,  281,  281,  237,
      229,  244,  245,  281,  270,  233,  241,  234,  236,  235,
      231,  281,  242,  243,  238,  240,  281,  246,  281,  281,
      239,  281,  247,  249,  281,  281,  281,  244,  245,  281,
      281,  241,  252,  281,  281,  253,  281,  242,  243,  254,
      248,  281,  256,  246,  250,  251,  281,  255,  247,  249,
      281,  281,  281,  257,  281,  258,  281,  281,  252,  262,

      281,  253,  259,  281,  254,  248,  260,  266,  256,  250,
      251,  261,  255,  269,  281,  263,  281,  264,  257,  281,
      258,  265,  281,  281,  267,  262,  281,  259,  281,  281,
      271,  260,  281,  266,  268,  275,  261,  273,  272,  269,
      263,  281,  264,  281,  274,  281,  281,  265,  281,  277,
      267,  281,  278,  281,  280,  271,  276,  281,  160,  160,
      268,  275,  273,  272,  158,  201,  279,  281,  281,  274,
      281,  281,  281,  158,  281,  277,  102,   97,  278,  281,
      280,  276,  281,   52,   48,  281,  102,   97,  281,   52,
       49,  279,   36,   36,   36,   36,   46,   46,   46,   46,

       96,   48,   96,   96,  100,  100,  281,   37,   37,    7,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      281,  281
    } ;

static yyconst flex_int16_t yy_chk[873] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    5,    5,    5,    5,    5,    5,    5,    5,
        5,   12,   12,   14,   14,   18,   19,   18,   21,   14,
       21,   18,   22,   24,   25,   15,   25,   26,   22,   26,
       33,   19,   33,   24,   25,   41,   41,  284,   32,   43,

       43,  280,   90,   18,  279,   14,   21,   18,   15,   34,
      278,   34,   25,   32,   22,   26,   19,  276,   33,   24,
       25,   90,    5,    5,    6,    6,    6,    6,    6,    6,
        6,    6,    6,   15,   20,   23,   20,   34,   32,   29,
      275,   29,   52,   23,   20,   29,   90,   52,   45,   45,
       23,   31,   66,   20,   45,   28,   66,   27,   20,  262,
       57,   31,   20,  261,   27,   28,   57,   29,   28,   23,
       20,   29,   27,   52,   28,   23,   27,   31,   20,  260,
       45,  257,   66,   20,    6,    6,   16,   31,   16,   16,
       27,   28,   57,   28,   51,   51,   16,   27,   53,   28,

       51,   27,   31,   53,   54,   54,   16,   61,   59,   58,
       54,   62,   16,  254,   16,   16,   56,   67,   56,   56,
       56,   59,   16,  253,   58,   61,   51,  108,  108,   53,
       67,   16,   62,   63,   60,   65,   54,   16,   30,   68,
       30,   68,   30,   69,   30,  251,   59,   60,   30,   58,
       61,   60,   69,   64,   63,   67,   64,   62,   65,   30,
       64,   70,   71,  250,   71,   72,   30,   68,   30,  248,
       30,   70,   60,   64,   30,  243,   60,   74,   69,   63,
       72,   73,   64,   65,   30,   77,   64,   78,   73,   75,
       71,   74,   74,   76,   78,   82,   81,   70,   64,   77,

       75,   86,   73,   83,   80,   72,   75,   84,   76,   80,
       87,   82,   87,   88,   73,   86,   74,   74,   85,   83,
       78,   81,   84,   89,   77,   85,   75,   73,   88,   93,
       94,   75,   92,   76,   91,   80,   82,   95,   87,   93,
       86,  156,  156,   94,   83,  241,   81,   84,  239,   92,
       89,   85,  238,   88,  237,   91,   99,   99,  101,  101,
       95,  102,   99,  231,  101,   93,  102,  103,   94,  105,
      226,  105,  103,  105,   92,   89,  109,  223,  115,  104,
       91,  104,  104,  104,  115,   95,  117,  106,   99,  106,
      101,  106,  102,  119,  110,  109,  120,  119,  103,  110,

      116,  118,  116,  118,  123,  121,  120,  122,  117,  125,
      115,  127,  130,  122,  126,  128,  124,  220,  123,  126,
      109,  132,  130,  119,  125,  110,  121,  127,  116,  118,
      124,  128,  120,  117,  129,  131,  135,  132,  134,  122,
      129,  131,  135,  123,  136,  126,  140,  218,  130,  125,
      139,  121,  127,  137,  134,  124,  128,  140,  143,  137,
      145,  217,  132,  138,  136,  141,  129,  131,  135,  138,
      146,  139,  147,  141,  142,  143,  146,  144,  147,  134,
      145,  148,  149,  140,  151,  137,  150,  142,  149,  136,
      144,  152,  144,  216,  148,  138,  139,  152,  215,  141,

      143,  161,  146,  161,  147,  145,  151,  150,  162,  153,
      210,  153,  142,  153,  149,  144,  154,  144,  154,  148,
      154,  157,  157,  152,  166,  165,  167,  169,  162,  161,
      171,  151,  150,  165,  174,  175,  171,  177,  179,  178,
      174,  206,  180,  169,  181,  167,  166,  182,  205,  203,
      202,  185,  201,  162,  175,  184,  177,  193,  179,  165,
      178,  180,  171,  181,  185,  197,  174,  182,  169,  183,
      167,  166,  187,  193,  184,  183,  188,  194,  187,  175,
      190,  177,  188,  179,  189,  178,  180,  192,  181,  185,
      189,  191,  182,  190,  195,  209,  265,  191,  193,  184,

      196,  183,  192,  199,  187,  198,  196,  200,  188,  199,
      211,  207,  208,  204,  209,  195,  189,  213,  190,  265,
      200,  204,  208,  191,  207,  198,  214,  192,  212,  211,
      213,  219,  196,  221,  212,  199,  186,  222,  224,  209,
      195,  222,  224,  176,  265,  200,  214,  204,  208,  207,
      198,  225,  219,  221,  211,  213,  227,  225,  235,  229,
      212,  228,  227,  229,  230,  232,  233,  222,  224,  234,
      236,  214,  233,  242,  244,  234,  240,  219,  221,  235,
      228,  245,  240,  225,  230,  232,  246,  236,  227,  229,
      249,  173,  247,  242,  172,  244,  255,  258,  233,  249,

      252,  234,  245,  264,  235,  228,  246,  258,  240,  230,
      232,  247,  236,  264,  266,  252,  268,  255,  242,  256,
      244,  256,  259,  267,  259,  249,  263,  245,  269,  270,
      266,  246,  170,  258,  263,  270,  247,  268,  267,  264,
      252,  271,  255,  273,  269,  272,  168,  256,  277,  272,
      259,  274,  273,  164,  277,  266,  271,  163,  160,  159,
      263,  270,  268,  267,  158,  155,  274,  133,  114,  269,
      113,  112,  111,  107,  100,  272,   98,   97,  273,   79,
      277,  271,   55,   50,   48,   46,   44,   39,   17,   13,
       11,  274,  282,  282,  282,  282,  283,  283,  283,  283,

      285,    9,  285,  285,  286,  286,    7,    4,    3,  281,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      281,  281,  281,  281,  281,  281,  281,  281,  281,  281,
      281,  281
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "fitsy++/envilex.L"
/* Copyright (C) 1999-2015
 * Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 * For conditions of distribution and use, see copyright notice in "copyright"
 */
#line 11 "fitsy++/envilex.L"
  #include <stdio.h>
  #include <stdlib.h>
  #include <string.h>

  #include "util.h"
  #include "enviparser.H"

  extern YYSTYPE* envilval;
  extern enviFlexLexer* envilexx;


/* rules */
#line 710 "fitsy++/envilex.C"

#define INITIAL 0
#define DISCARD 1
#define BRACKET 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
#define ECHO LexerOutput( yytext, yyleng )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
\
	if ( (result = LexerInput( (char *) buf, max_size )) < 0 ) \
		YY_FATAL_ERROR( "input in flex scanner failed" );

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) LexerError( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
#define YY_DECL int yyFlexLexer::yylex()
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 30 "fitsy++/envilex.L"


#line 815 "fitsy++/envilex.C"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = & std::cin;

		if ( ! yyout )
			yyout = & std::cout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 282 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 281 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 32 "fitsy++/envilex.L"
{ // special case-- #\n
		  BEGIN INITIAL;
		  yyless(0);             // put back the terminator
		  strcpy(envilval->str,""); // feed a blank string
		  return STRING;
		}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 39 "fitsy++/envilex.L"
{  // Discard reset of line
		  BEGIN INITIAL;
		  int ll = yyleng <(ENVIPARSERSIZE-1) ? yyleng:(ENVIPARSERSIZE-1);
		  strncpy(envilval->str,yytext,ll);
	          envilval->str[ll] = '\0';
		  return STRING;
		}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 47 "fitsy++/envilex.L"
{
                  BEGIN BRACKET;
                  return '{';
                }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 52 "fitsy++/envilex.L"
{
		  BEGIN INITIAL;
                  return '}';
                }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 57 "fitsy++/envilex.L"
{return DEBUG_;}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 58 "fitsy++/envilex.L"
{return ON_;}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 59 "fitsy++/envilex.L"
{return OFF_;}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 61 "fitsy++/envilex.L"
{return AVERAGE_;}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 62 "fitsy++/envilex.L"
{return BAND_;}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 63 "fitsy++/envilex.L"
{return BANDS_;}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 64 "fitsy++/envilex.L"
{return BBL_;}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 65 "fitsy++/envilex.L"
{return BIL_;}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 66 "fitsy++/envilex.L"
{return BIP_;}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 67 "fitsy++/envilex.L"
{return BSQ_;}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 68 "fitsy++/envilex.L"
{return BYTE_;}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 69 "fitsy++/envilex.L"
{return ENVI_;}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 70 "fitsy++/envilex.L"
{return DATA_;}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 71 "fitsy++/envilex.L"
{return DEFAULT_;}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 72 "fitsy++/envilex.L"
{return DESCRIPTION_;}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 73 "fitsy++/envilex.L"
{return FACTOR_;}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 74 "fitsy++/envilex.L"
{return FRAME_;}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 75 "fitsy++/envilex.L"
{return FILE_;}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 76 "fitsy++/envilex.L"
{return FWHM_;}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 77 "fitsy++/envilex.L"
{return GAIN_;}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 78 "fitsy++/envilex.L"
{return HEADER_;}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 79 "fitsy++/envilex.L"
{return INFO_;}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 80 "fitsy++/envilex.L"
{return IGNORE_;}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 81 "fitsy++/envilex.L"
{return INTERLEAVE_;}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 82 "fitsy++/envilex.L"
{return LIMITS_;}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 83 "fitsy++/envilex.L"
{return LINES_;}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 84 "fitsy++/envilex.L"
{return MAJOR_;}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 85 "fitsy++/envilex.L"
{return MAP_;}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 86 "fitsy++/envilex.L"
{return MINOR_;}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 87 "fitsy++/envilex.L"
{return NAMES_;}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 88 "fitsy++/envilex.L"
{return OFFSET_;}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 89 "fitsy++/envilex.L"
{return OFFSETS_;}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 90 "fitsy++/envilex.L"
{return ORDER_;}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 91 "fitsy++/envilex.L"
{return PIXEL_;}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 92 "fitsy++/envilex.L"
{return PIXELS_;}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 93 "fitsy++/envilex.L"
{return PLOT_;}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 94 "fitsy++/envilex.L"
{return PROJECTION_;}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 95 "fitsy++/envilex.L"
{return RANGE_;}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 96 "fitsy++/envilex.L"
{return REFLECTANCE_;}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 97 "fitsy++/envilex.L"
{return SAMPLES_;}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 98 "fitsy++/envilex.L"
{return SCALE_;}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 99 "fitsy++/envilex.L"
{return SCANNER_;}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 100 "fitsy++/envilex.L"
{return SENSOR_;}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 101 "fitsy++/envilex.L"
{return SIZE_;}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 102 "fitsy++/envilex.L"
{return STRETCH_;}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 103 "fitsy++/envilex.L"
{return TITLES_;}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 104 "fitsy++/envilex.L"
{return TYPE_;}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 105 "fitsy++/envilex.L"
{return UNITS_;}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 106 "fitsy++/envilex.L"
{return VALUE_;}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 107 "fitsy++/envilex.L"
{return VALUES_;}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 108 "fitsy++/envilex.L"
{return WAVELENGTH_;}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 111 "fitsy++/envilex.L"
{ // Integer
		  envilval->integer = atoi(yytext);
		  return INT;
		}
	YY_BREAK
case 57:
#line 117 "fitsy++/envilex.L"
case 58:
YY_RULE_SETUP
#line 117 "fitsy++/envilex.L"
{ // Real Number
		  envilval->real = atof(yytext);
		  return REAL;
		}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 123 "fitsy++/envilex.L"
{ // General String
		  int ll = yyleng <(ENVIPARSERSIZE-1) ? yyleng:(ENVIPARSERSIZE-1);
		  strncpy(envilval->str,yytext,ll);
	          envilval->str[ll] = '\0';
		  return STRING;
		}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 130 "fitsy++/envilex.L"
{
                  return ',';
                }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 134 "fitsy++/envilex.L"
{ // White Spaces
		} 
	YY_BREAK
case 62:
/* rule 62 can match eol */
YY_RULE_SETUP
#line 137 "fitsy++/envilex.L"
{ // linefeed
		}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 140 "fitsy++/envilex.L"
{ // other chars, eat it
                }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 143 "fitsy++/envilex.L"
{ // Integer
		  envilval->integer = atoi(yytext);
		  return INT;
		}
	YY_BREAK
case 65:
#line 149 "fitsy++/envilex.L"
case 66:
YY_RULE_SETUP
#line 149 "fitsy++/envilex.L"
{ // Real Number
		  envilval->real = atof(yytext);
		  return REAL;
		}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 155 "fitsy++/envilex.L"
{ // General String
		  int ll = yyleng <(ENVIPARSERSIZE-1) ? yyleng:(ENVIPARSERSIZE-1);
		  strncpy(envilval->str,yytext,ll);
	          envilval->str[ll] = '\0';
		  return STRING;
		}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 162 "fitsy++/envilex.L"
{ // White Spaces
		} 
	YY_BREAK
case 69:
/* rule 69 can match eol */
YY_RULE_SETUP
#line 165 "fitsy++/envilex.L"
{ // windows line feed
		  return '\n';
		}
	YY_BREAK
case 70:
/* rule 70 can match eol */
YY_RULE_SETUP
#line 169 "fitsy++/envilex.L"
{ // linefeed
		  return '\n';
		}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(DISCARD):
case YY_STATE_EOF(BRACKET):
#line 173 "fitsy++/envilex.L"
{ // eof
		  return EOF_;
		}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 177 "fitsy++/envilex.L"
{ // Else, return the char
		  return yytext[0];
		}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 181 "fitsy++/envilex.L"
ECHO;
	YY_BREAK
#line 1311 "fitsy++/envilex.C"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* The contents of this function are C++ specific, so the () macro is not used.
 */
yyFlexLexer::yyFlexLexer( std::istream* arg_yyin, std::ostream* arg_yyout )
{
	yyin = arg_yyin;
	yyout = arg_yyout;
	yy_c_buf_p = 0;
	yy_init = 0;
	yy_start = 0;
	yy_flex_debug = 0;
	yylineno = 1;	// this will only get updated if %option yylineno

	yy_did_buffer_switch_on_eof = 0;

	yy_looking_for_trail_begin = 0;
	yy_more_flag = 0;
	yy_more_len = 0;
	yy_more_offset = yy_prev_more_offset = 0;

	yy_start_stack_ptr = yy_start_stack_depth = 0;
	yy_start_stack = NULL;

	yy_buffer_stack = 0;
	yy_buffer_stack_top = 0;
	yy_buffer_stack_max = 0;

	yy_state_buf = 0;

}

/* The contents of this function are C++ specific, so the () macro is not used.
 */
yyFlexLexer::~yyFlexLexer()
{
	delete [] yy_state_buf;
	envifree(yy_start_stack  );
	yy_delete_buffer( YY_CURRENT_BUFFER );
	envifree(yy_buffer_stack  );
}

/* The contents of this function are C++ specific, so the () macro is not used.
 */
void yyFlexLexer::switch_streams( std::istream* new_in, std::ostream* new_out )
{
	if ( new_in )
		{
		yy_delete_buffer( YY_CURRENT_BUFFER );
		yy_switch_to_buffer( yy_create_buffer( new_in, YY_BUF_SIZE  ) );
		}

	if ( new_out )
		yyout = new_out;
}

#ifdef YY_INTERACTIVE
size_t yyFlexLexer::LexerInput( char* buf, size_t /* max_size */ )
#else
size_t yyFlexLexer::LexerInput( char* buf, size_t max_size )
#endif
{
	if ( yyin->eof() || yyin->fail() )
		return 0;

#ifdef YY_INTERACTIVE
	yyin->get( buf[0] );

	if ( yyin->eof() )
		return 0;

	if ( yyin->bad() )
		return -1;

	return 1;

#else
	(void) yyin->read( buf, max_size );

	if ( yyin->bad() )
		return -1;
	else
		return yyin->gcount();
#endif
}

void yyFlexLexer::LexerOutput( const char* buf, size_t size )
{
	(void) yyout->write( buf, size );
}

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
int yyFlexLexer::yy_get_next_buffer()
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					envirealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) envirealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    yy_state_type yyFlexLexer::yy_get_previous_state()
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 282 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    yy_state_type yyFlexLexer::yy_try_NUL_trans( yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 282 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 281);

	return yy_is_jam ? 0 : yy_current_state;
}

    void yyFlexLexer::yyunput( int c, register char* yy_bp)
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

    int yyFlexLexer::yyinput()
{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyFlexLexer::yyrestart( std::istream* input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yyFlexLexer::yy_switch_to_buffer( YY_BUFFER_STATE new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

    void yyFlexLexer::yy_load_buffer_state()
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yyFlexLexer::yy_create_buffer( std::istream* file, int size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) envialloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) envialloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yyFlexLexer::yy_delete_buffer( YY_BUFFER_STATE b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		envifree((void *) b->yy_ch_buf  );

	envifree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    void yyFlexLexer::yy_init_buffer( YY_BUFFER_STATE b, std::istream* file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

	b->yy_is_interactive = 0;
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yyFlexLexer::yy_flush_buffer( YY_BUFFER_STATE b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yyFlexLexer::yypush_buffer_state (YY_BUFFER_STATE new_buffer)
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yyFlexLexer::yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
void yyFlexLexer::yyensure_buffer_stack(void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)envialloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)envirealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

    void yyFlexLexer::yy_push_state( int new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) envialloc(new_size  );

		else
			(yy_start_stack) = (int *) envirealloc((void *) (yy_start_stack),new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(new_state);
}

    void yyFlexLexer::yy_pop_state()
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

    int yyFlexLexer::yy_top_state()
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

void yyFlexLexer::LexerError( yyconst char msg[] )
{
    	std::cerr << msg << std::endl;
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *envialloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *envirealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void envifree (void * ptr )
{
	free( (char *) ptr );	/* see envirealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 181 "fitsy++/envilex.L"



void enviDiscard(int doit)
{
  if (envilexx)
    envilexx->begin(DISCARD, doit);
}

void enviFlexLexer::begin(int which, int doit)
{
  BEGIN which;
  if (doit)
    yyless(0);
}

